@@ -1,3 +1,5 @@
+# noqa: D100
+
 # stdlib
 from decimal import Decimal  # pragma: no cover
 from typing import Any, List, Optional, Tuple  # pragma: no cover
@@ -18,7 +20,7 @@ def demo(
 		j: Optional[List[str]] = None,
 		k: Optional[List[str]] = None,
 		l: str = '',
-		m: str = "\t",
+		m: str = '\t',
 		n: Any = ...,
 		):  # pragma: no cover
 	"""
@@ -45,5 +47,5 @@ def demo(
 
 	The description for ``d`` lacked a fullstop at the end, but one was added automatically.
 
-	The default value of ``n`` was ``Ellipsis``, but it wasn't shown.
+	The default value of ``n`` was :py:obj:`Ellipsis`, but it wasn't shown.
 	"""
